@@ -1,29 +1,29 @@
+import logging
 import os
 import time
 import subprocess
-import logging
 
 from requests import exceptions
 
-from python_kemptech_api.capabilities import CAPABILITIES, DEFAULT
 from python_kemptech_api import utils
-from .generic import (
-    HttpClient, AccessInfoMixin)
-from .api_xml import (
+from python_kemptech_api.api_xml import (
     get_data_field,
     is_successful,
     get_data,
-    get_error_msg)
-from .exceptions import (
+    get_error_msg
+)
+from python_kemptech_api.capabilities import CAPABILITIES, DEFAULT
+from python_kemptech_api.exceptions import (
     LoadMasterParameterError,
     KempTechApiException,
     BackupFailed,
-    ValidationError,
     CommandNotAvailableException,
     UserAlreadyExistsException,
     DownloadUserCertFailed,
-    NotVirtualServiceInstanceError)
-from .objects import (
+    NotVirtualServiceInstanceError
+)
+from python_kemptech_api.generic import HttpClient, AccessInfoMixin
+from python_kemptech_api.objects import (
     VirtualService,
     Certificate,
     Sso,
@@ -33,8 +33,9 @@ from .objects import (
     Cluster,
     Range,
     CustomLocation,
-    Interface)
-from .utils import (
+    Interface
+)
+from python_kemptech_api.utils import (
     send_response,
     validate_port,
     validate_ip,
@@ -42,14 +43,16 @@ from .utils import (
     get_api_bool_string,
     cast_to_list,
     get_dict_entry_as_list,
-    get_sub_vs_list_from_data, build_object, list_object)
+    get_sub_vs_list_from_data,
+    build_object,
+    list_object
+)
 
 log = logging.getLogger(__name__)
 
 
 class BaseKempAppliance(HttpClient, AccessInfoMixin):
-    def __init__(self, ip, username=None, password=None, port=443,
-                 cert=None):
+    def __init__(self, ip, username=None, password=None, port=443, cert=None):
         self.ip_address = ip
         self.username = username
         self.password = password
@@ -146,6 +149,10 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
 
     @property
     def license(self):
+        """Current license on the LoadMaster
+
+        :return: License information
+        """
         response = self._get("/licenseinfo")
 
         if is_successful(response):
@@ -180,6 +187,10 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
 
     @property
     def interfaces(self):
+        """ Dictionary of named interfaces
+
+        :return: Dict with interface name and Interface instance key / value pairs.
+        """
         return {interface.name: interface
                 for interface in self.get_interfaces()}
 
@@ -259,7 +270,6 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
             if status_code == 404:
                 self._do_request_no_api('progs/doconfig/enableapi/set/yes')
                 status_code = self._do_request_no_api('progs/status/logout')
-                print(status_code)
                 if status_code != 200:
                     raise KempTechApiException(code=status_code)
                 if health_check_api:
@@ -425,35 +435,36 @@ class BaseKempAppliance(HttpClient, AccessInfoMixin):
         response = self._get('/killaslinstance')
         return send_response(response)
 
-    def show_interface(self, interface_id=0):
-        # Deprecated, use Interface object
-        if not isinstance(interface_id, int):
-            raise ValidationError('"interface_id" must be an integer')
-        response = self._get('/showiface', {"interface": interface_id})
-        data = get_data(response)
-        interface = data["Interface"]
-        if interface["IPAddress"] is not None:
-            # Address/cidr is set in this case and can safely be split
-            address_cidr_split = interface["IPAddress"].split("/")
-            interface["IPAddress"] = address_cidr_split[0]
-            interface["cidr"] = address_cidr_split[1]
-        return interface
-
     def get_interfaces(self):
+        interfaces = []
         try:
-            response = self._get('/stats')
+            response = self._get('/showiface')
             data = get_data(response)
-            xml_object = data.get('Network', [])
-        except KempTechApiException:
-            xml_object = []
+            interfaces_data = data.get('Interface', [])
+            for iface_data in interfaces_data:
+                iface = build_object(Interface, self.access_info, iface_data)
+                interfaces.append(iface)
+            return interfaces
+        except KempTechApiException as e:
+            # If showiface does not support listing of all interfaces (possibly due to
+            # older version loadmasters) do it the hard way by doing it one by one getting
+            # the IDs from /access/stats.
+            # This will cause N+1 API calls to occur, N being the number of interfaces.
+            if hasattr(e, "status_code") and e.status_code == 422:
+                try:
+                    response = self._get('/stats')
+                    data = get_data(response)
+                    xml_object = data.get('Network', [])
+                except KempTechApiException:
+                    xml_object = []
 
-        obj_list = []
-
-        for k, v in xml_object.items():
-            obj = self.get_interface(v['ifaceID'])
-            obj.name = k
-            obj_list.append(obj)
-        return obj_list
+                for k, v in xml_object.items():
+                    obj = self.get_interface(v['ifaceID'])
+                    obj.name = k
+                    interfaces.append(obj)
+                return interfaces
+            else:
+                raise
 
     def get_interface(self, interface):
         response = self._get("/showiface", {"interface": interface})
