@@ -1698,7 +1698,8 @@ class Interface(BaseKempObject):
 
     @property
     def address(self):
-        return self.addr.split("/")[0]
+        # self.addr can be None as it is not mandatory for an interface to have an address
+        return self.addr.split("/")[0] if self.addr is not None else None
 
     @address.setter
     def address(self, value):
