@@ -1,6 +1,3 @@
-from itertools import chain
-from unittest import skip
-
 from nose.tools import (
     assert_equal, assert_raises, assert_true,
     assert_is_none, assert_not_in, assert_greater, assert_less,
@@ -25,7 +22,7 @@ from python_kemptech_api.models import LoadMaster, BaseKempAppliance
 import python_kemptech_api.exceptions as exceptions
 
 
-def  test_endpoint():
+def test_endpoint():
     lm = LoadMaster('ip', 'user', 'pw', 'port')
     expected = "https://user:pw@ip:port/access"
     assert_equal(expected, lm.endpoint)
@@ -47,6 +44,7 @@ def test_send_response_fail():
             with assert_raises(exceptions.KempTechApiException):
                 utils.send_response('any_response')
 
+
 def test_repr():
     lm = LoadMaster('192.168.0.1', 'user', 'pw', 432)
     assert_equal(str(lm), '192.168.0.1:432')
@@ -112,39 +110,6 @@ class Test_virtual_service_crud:
         vs = self.lm.create_virtual_service("1.1.1.2", 90, "tcp")
         assert_equal(isinstance(vs, VirtualService), True)
 
-
-class Test_get_virtual_services:
-
-    def setup(self):
-        self.lm = LoadMaster("1.1.1.1", "bal", "2fourall")
-
-    @skip("After performance refactoring this test no longer makes sense, "
-          "it needs to be rewritten")
-    def test_data_exists(self):
-        with patch.object(LoadMaster, 'build_virtual_service') as build_virtual_service:
-            with patch.object(models, 'get_data') as get_data:
-                with patch.object(LoadMaster, '_get'):
-                    get_data.return_value = {
-                        "VS": [{"VSAddress": "1.1.1.1", "VSPort": 80, "Protocol": "tcp", "ForceL7": "Y"},
-                               {"VSAddress": "1.1.1.2", "VSPort": 443, "Protocol": "tcp", "ForceL7": "N"}]}
-                    res = self.lm.get_virtual_services()
-
-        vs1 = [x for x in res if x.vs == "1.1.1.1"].pop()
-        vs2 = [x for x in res if x.vs == "1.1.1.2"].pop()
-
-        assert_equal(vs1.vs, "1.1.1.1")
-        assert_equal(vs2.vs, "1.1.1.2")
-
-        assert_equal(vs1.port, 80)
-        assert_equal(vs2.port, 443)
-
-        assert_equal(vs1.prot, "tcp")
-        assert_equal(vs2.prot, "tcp")
-
-        assert_equal(vs1.forcel7, "Y")
-        assert_equal(vs2.forcel7, "N")
-
-
     def test_no_data_exists(self):
         with patch.object(LoadMaster, 'build_virtual_service') as build_virtual_service:
             with patch.object(models, 'get_data') as get_data:
@@ -155,6 +120,7 @@ class Test_get_virtual_services:
         expected = []
         assert_equal(res, expected)
 
+
 class Test_get_virtual_service:
 
     def setup(self):
@@ -181,32 +147,6 @@ class Test_get_virtual_service:
         assert_equal(res, sentinel.vs)
 
 
-class Test_show_interface:
-
-    def setup(self):
-        self.lm = LoadMaster("1.1.1.1", "bal", "2fourall")
-
-    def test_show_interface_when_id_is_nan(self):
-        with assert_raises(exceptions.ValidationError):
-            self.lm.show_interface("1")
-
-    def test_show_interface(self):
-        with patch.object(LoadMaster, "_get"):
-            with patch.object(models, "get_data") as get_data:
-                get_data.return_value = {"Interface": {"IPAddress": "10.154.190.110/16"}}
-                interface = self.lm.show_interface(0)
-                assert_equal(interface["IPAddress"], "10.154.190.110")
-                assert_equal(interface["cidr"], "16")
-
-    def test_show_interface_no_ip(self):
-        with patch.object(LoadMaster, "_get") as _get:
-            with patch.object(models, "get_data") as get_data:
-                get_data.return_value = {"Interface": {"IPAddress": None}}
-                interface = self.lm.show_interface(0)
-                assert_equal(interface["IPAddress"], None)
-                assert_not_in("cidr", interface)
-
-
 class TestLmApiWrapperCalls:
 
     def setup(self):
@@ -281,21 +221,6 @@ class TestLmApiWrapperCalls:
         params = {'name': name}
         self.lm._get.assert_called_with('/deltemplate', parameters=params)
 
-    @skip("test_apply_template needs to be recreated to suite Andrew's version of the function.")
-    def test_apply_template(self):
-        ip = '1.1.1.1'
-        port = 80
-        prot = 'tcp'
-        name = 'template_name'
-        self.lm.apply_template(ip, port, prot, name)
-        params = {
-            'vs': ip,
-            'port': port,
-            'prot': prot,
-            'name': name,
-        }
-        self.lm._get.assert_called_with('/addvs', parameters=params)
-
     def test_get_sdn_info(self):
         self.lm.get_sdn_info()
         self.lm._get.assert_called_with('/sdninfo')
